@@ -1,8 +1,8 @@
 from .authentication import Authentication, BearerTokenAuth
 from .client import Client
 from .config import BaseUrlConfig, RequestConfig, ApiResponse, ApiConfiguration, DictApiConfiguration, \
-    JsonApiConfiguration
-from .exceptions import ApiException
+    JsonApiConfiguration, SwaggerApiConfiguration
+from .exceptions import ApiException, ConfigurationException
 from .util import fill_query_params, endpoint
 
 __all__ = [
@@ -15,7 +15,9 @@ __all__ = [
     'ApiConfiguration',
     'DictApiConfiguration',
     'JsonApiConfiguration',
+    'SwaggerApiConfiguration',
     'ApiException',
+    'ConfigurationException',
     'fill_query_params',
     'endpoint'
 ]
