@@ -2,8 +2,6 @@ from rest_client.base.config import RequestConfig
 
 
 def fill_query_params(query, *args):
-    print(query)
-    print(args)
     return query.format(*args)
 
 
@@ -13,7 +11,7 @@ def endpoint(path: str, name: str = None, method: str = 'GET', options: dict = N
             kwargs.update({
                 'request_config': RequestConfig(
                     path=fill_query_params(path, *args),
-                    name=name,
+                    name=name or path,
                     method=method,
                     options=options)
             })
